@@ -313,9 +313,9 @@ static bool probe_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       return TRUE;
     }
 
-    case XS_PARSE_KEYWORD_PARENSCOPE:
+    case XS_PARSE_KEYWORD_PARENS:
       if(piece->type & XPK_TYPEFLAG_MAYBEPARENS)
-        croak("TODO: probe_piece on type=PARENSCOPE+MAYBEPARENS");
+        croak("TODO: probe_piece on type=PARENS+MAYBEPARENS");
 
       if(lex_peek_unichar(0) != '(')
         return FALSE;
@@ -323,21 +323,21 @@ static bool probe_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       parse_piece(aTHX_ argsv, argidx, piece, hookdata);
       return TRUE;
 
-    case XS_PARSE_KEYWORD_BRACKETSCOPE:
+    case XS_PARSE_KEYWORD_BRACKETS:
       if(lex_peek_unichar(0) != '[')
         return FALSE;
 
       parse_piece(aTHX_ argsv, argidx, piece, hookdata);
       return TRUE;
 
-    case XS_PARSE_KEYWORD_BRACESCOPE:
+    case XS_PARSE_KEYWORD_BRACES:
       if(lex_peek_unichar(0) != '{')
         return FALSE;
 
       parse_piece(aTHX_ argsv, argidx, piece, hookdata);
       return TRUE;
 
-    case XS_PARSE_KEYWORD_CHEVRONSCOPE:
+    case XS_PARSE_KEYWORD_CHEVRONS:
       if(lex_peek_unichar(0) != '<')
         return FALSE;
 
@@ -666,6 +666,10 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       (*argidx)++;
       return;
 
+    case XS_PARSE_KEYWORD_INTRO_MY:
+      intro_my();
+      return;
+
     case XS_PARSE_KEYWORD_INFIX:
     {
       if(!XSParseInfix_parse(aTHX_ piece->u.c, &THISARG.infix))
@@ -728,7 +732,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       }
       return;
 
-    case XS_PARSE_KEYWORD_PARENSCOPE:
+    case XS_PARSE_KEYWORD_PARENS:
     {
       bool has_paren = (lex_peek_unichar(0) == '(');
 
@@ -758,7 +762,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       return;
     }
 
-    case XS_PARSE_KEYWORD_BRACKETSCOPE:
+    case XS_PARSE_KEYWORD_BRACKETS:
       if(is_optional) {
         THISARG.i = 0;
         (*argidx)++;
@@ -775,7 +779,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
 
       return;
 
-    case XS_PARSE_KEYWORD_BRACESCOPE:
+    case XS_PARSE_KEYWORD_BRACES:
       if(is_optional) {
         THISARG.i = 0;
         (*argidx)++;
@@ -792,7 +796,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
 
       return;
 
-    case XS_PARSE_KEYWORD_CHEVRONSCOPE:
+    case XS_PARSE_KEYWORD_CHEVRONS:
       if(is_optional) {
         THISARG.i = 0;
         (*argidx)++;
@@ -836,6 +840,12 @@ static int parse(pTHX_ OP **op, struct Registration *reg)
   SV *argsv = newSV(maxargs * sizeof(XSParseKeywordPiece));
   SAVEFREESV(argsv);
 
+  bool is_blockscope = hooks->flags & XPK_FLAG_BLOCKSCOPE;
+
+  int floor;
+  if(is_blockscope)
+    floor = block_start(TRUE);
+
   size_t argidx = 0;
   if(hooks->build)
     parse_pieces(aTHX_ argsv, &argidx, hooks->pieces, reg->hookdata);
@@ -879,6 +889,9 @@ static int parse(pTHX_ OP **op, struct Registration *reg)
   else
     ret = (*hooks->build1)(aTHX_ op, args + 0, reg->hookdata);
 
+  if(is_blockscope)
+    *op = block_end(floor, *op);
+
   switch(hooks->flags & (XPK_FLAG_EXPR|XPK_FLAG_STMT)) {
     case XPK_FLAG_EXPR:
       if(ret && (ret != KEYWORD_PLUGIN_EXPR))
